package stats
import "github.com/ydb-platform/ydb-go-sdk/v3/internal/stats"
Index ¶
- type CompilationStats
- type OperationStats
- type Phase
- type QueryPhase
- type QueryStats
- type TableAccess
Types ¶
type CompilationStats ¶
CompilationStats holds query compilation statistics.
type OperationStats ¶
type Phase ¶
type Phase struct {
Duration time.Duration
TableAccess []TableAccess
CPUTime time.Duration
AffectedShards uint64
LiteralPhase bool
}
type QueryPhase ¶
type QueryPhase interface {
// NextTableAccess returns next accessed table within query execution phase.
// If ok flag is false, then there are no more accessed tables and t is invalid.
NextTableAccess() (t *TableAccess, ok bool)
// TableAccess is a range iterator over query execution phase's accessed tables.
TableAccess() xiter.Seq[*TableAccess]
Duration() time.Duration
CPUTime() time.Duration
AffectedShards() uint64
IsLiteralPhase() bool
}
QueryPhase holds query execution phase statistics.
type QueryStats ¶
type QueryStats interface {
ProcessCPUTime() time.Duration
Compilation() (c *CompilationStats)
QueryPlan() string
QueryAST() string
TotalCPUTime() time.Duration
TotalDuration() time.Duration
// NextPhase returns next execution phase within query.
// If ok flag is false, then there are no more phases and p is invalid.
NextPhase() (p QueryPhase, ok bool)
// QueryPhases is a range iterator over query phases.
QueryPhases() xiter.Seq[QueryPhase]
}
QueryStats holds query execution statistics.
func FromQueryStats ¶
func FromQueryStats(pb *Ydb_TableStats.QueryStats) QueryStats
type TableAccess ¶
type TableAccess struct {
Name string
Reads OperationStats
Updates OperationStats
Deletes OperationStats
PartitionsCount uint64
}
TableAccess contains query execution phase's table access statistics.
Source Files ¶
- Version
- v3.115.0 (latest)
- Published
- Aug 17, 2025
- Platform
- linux/amd64
- Imports
- 3 packages
- Last checked
- 8 months ago –
Tools for package owners.