package indexed
import "github.com/ydb-platform/ydb-go-sdk/v3/table/result/indexed"
Index ¶
Types ¶
type Optional ¶
type Optional interface{}
Optional is a type scan destination of optional ydb values Optional must be a double pointer value destination
This is a proxy type for preparing go1.18 type set constrains such as
type Optional interface {
**int8 | **int64 | **string | types.Scanner | json.Unmarshaler
}
or alias such as
type Optional *Required
type Required ¶
type Required interface{}
Required is a type scan destination of non-optional ydb values Required must be a single pointer value destination
This is a proxy type for preparing go1.18 type set constrains such as
type Required interface {
*int8 | *int64 | *string | types.Scanner | json.Unmarshaler
}
type RequiredOrOptional ¶
type RequiredOrOptional interface{}
RequiredOrOptional is a type scan destination of ydb values This is a proxy type for preparing go1.18 type set constrains such as
type valueType interface {
Required | Optional
}
Source Files ¶
- Version
- v3.115.0 (latest)
- Published
- Aug 17, 2025
- Platform
- linux/amd64
- Last checked
- 8 months ago –
Tools for package owners.